==> dart_ip-0.1.3.tar.gz: lib/datx/city.dart <==
import 'dart:io';
import 'dart:convert';
import 'utils.dart';
import 'package:path/path.dart' as path;

class City{
    List<int> data;
    int indexSize = 0;

    City({String datFile}) {
        if (datFile == null) {
//            datFile = "${dirname(Platform.script.toString())}/17monipdb.datx";
//        datFile = path.join(".", "17monipdb.datx").toString();
        datFile = path.join(path.absolute("."), "lib", "datx", "17monipdb.datx");
        print(datFile);
        }
        File file = File(datFile);
        data = file.readAsBytesSync();
        indexSize = bytes2Long(data[0], data[1], data[2], data[3]);
    }

    List<String> find(String ip){
        if (verifyIpv4(ip)){
            return [];
        }
        int low = 0;
        int mid = 0;
        int high = ((indexSize - 262144 - 262148) / 9).toInt() - 1;

        int start;
        int end;
        int pos0;
        int pos1;
        int l;
        int off;
        String tmp;
        int val = ip2Long(ip);

        while (low <= high){
            mid = ((low + high) / 2).toInt();
            pos0 = mid * 9 + 262148;
            start = 0;
            if (mid > 0 ){
                pos1 = (mid - 1) * 9 + 262148;
                start = bytes2Long(data[pos1], data[pos1+1], data[pos1+2], data[pos1+3]);
                start += 1;
            }

            end = bytes2Long(data[pos0], data[pos0+1], data[pos0+2], data[pos0+3]);

            if (val < start) {
                high = mid - 1;
            } else if (val > end) {
                low = mid + 1;
            }else{
                off = data[pos0+6] << 16 | data[pos0+5] << 8 | data[pos0+4];
                l = data[pos0+7] << 8 | data[pos0+8];
                pos0 = off - 262144 + indexSize;
                tmp = Utf8Decoder().convert(data.sublist(pos0, pos0+l));
                return tmp.split("\t");
            }
        }
    }
}

==> dart_ip-0.1.4.tar.gz: lib/datx/city.dart <==
import 'dart:io';
import 'dart:convert';
import 'utils.dart';
import 'package:path/path.dart' as path;

class City{
    List<int> data;
    int indexSize = 0;

    City({String datFile}) {
        if (datFile == null) {
        datFile = path.join(path.absolute(path.dirname(".")), "lib", "datx", "17monipdb.datx");
        print(datFile);
        }
        File file = File(datFile);
        data = file.readAsBytesSync();
        indexSize = bytes2Long(data[0], data[1], data[2], data[3]);
    }

    List<String> find(String ip){
        if (verifyIpv4(ip)){
            return [];
        }
        int low = 0;
        int mid = 0;
        int high = ((indexSize - 262144 - 262148) / 9).toInt() - 1;

        int start;
        int end;
        int pos0;
        int pos1;
        int l;
        int off;
        String tmp;
        int val = ip2Long(ip);

        while (low <= high){
            mid = ((low + high) / 2).toInt();
            pos0 = mid * 9 + 262148;
            start = 0;
            if (mid > 0 ){
                pos1 = (mid - 1) * 9 + 262148;
                start = bytes2Long(data[pos1], data[pos1+1], data[pos1+2], data[pos1+3]);
                start += 1;
            }

            end = bytes2Long(data[pos0], data[pos0+1], data[pos0+2], data[pos0+3]);

            if (val < start) {
                high = mid - 1;
            } else if (val > end) {
                low = mid + 1;
            }else{
                off = data[pos0+6] << 16 | data[pos0+5] << 8 | data[pos0+4];
                l = data[pos0+7] << 8 | data[pos0+8];
                pos0 = off - 262144 + indexSize;
                tmp = Utf8Decoder().convert(data.sublist(pos0, pos0+l));
                return tmp.split("\t");
            }
        }
    }
}
